@@ -780,6 +780,35 @@ class DbbrainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeRedisTopKeyPrefixList(self, request):
+        """查询redis实例top key前缀列表。
+
+        :param request: Request instance for DescribeRedisTopKeyPrefixList.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.DescribeRedisTopKeyPrefixListRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.DescribeRedisTopKeyPrefixListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeRedisTopKeyPrefixList", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeRedisTopKeyPrefixListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeSecurityAuditLogDownloadUrls(self, request):
         """查询安全审计日志导出文件下载链接。目前日志文件下载仅提供腾讯云内网地址，请通过广州地域的腾讯云服务器进行下载。
 
@@ -955,7 +984,7 @@ class DbbrainClient(AbstractClient):
 
 
     def DescribeSqlTemplate(self, request):
-        """查询SQL模版。
+        """查询SQL模板。
 
         :param request: Request instance for DescribeSqlTemplate.
         :type request: :class:`tencentcloud.dbbrain.v20210527.models.DescribeSqlTemplateRequest`
